==> nextcloud-15.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/nl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info niet beschikbaar",
    "Load average" : "Gemiddelde belasting",
    "Last minute" : "Laatste minuut",
    "Memory info not available" : "Geheugeninfo niet beschikbaar",
    "Total" : "Totaal",
    "Current usage" : "Huidig gebruik",
    "Users" : "Gebruikers",
    "Groups" : "Groepen",
    "Links" : "Links",
    "Mails" : "Mails",
    "Federated sent" : "Gefedereerd verstuurd",
    "Federated received" : "Gefedereerd ontvangen",
    "Talk conversations" : "Talk gesprek",
    "Last 24 hours" : "Laatste 24 uur",
    "Last 1 hour" : "Laatste uur",
    "Last 5 mins" : "Laatste 5 minuten",
    "Copy" : "Kopiëren",
    "Copied!" : "Gekopieerd",
    "Not supported!" : "Niet ondersteund",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "Monitoring" : "Monitoren",
    "Monitoring app with useful server information" : "Monitor app met nuttige serverinformatie",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Toont nuttige serverinformatie, zoals CPU belasting, RAM gebruik, disk gebruik, aantal gebruikers, etc.",
    "CPU load" : "CPU belasting",
    "Memory usage" : "Geheugengebruik",
    "Active users" : "Actieve gebruikers",
    "Shares" : "Shares",
    "Storage" : "Opslag",
    "Users:" : "Gebruikers:",
    "Files:" : "Bestanden:",
    "Storages:" : "Opslag:",
    "Free Space:" : "Vrije ruimte:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Versie:",
    "Apps installed:" : "Apps geïnstalleerd:",
    "Apps updates available:" : "App updates beschikbaar:",
    "PHP" : "PHP",
    "Memory Limit:" : "Geheugenlimiet:",
    "Max Execution Time:" : "Max verwerkingstijd:",
    "Upload max size:" : "Max uploadomvang:",
    "Database" : "Database",
    "Type:" : "Type:",
    "Size:" : "Grootte:",
    "External monitoring tool" : "Externe monitoring tool",
    "You can connect an external monitoring tool by using this end point:" : "Je kunt een externe monitor-tool verbinden door dit end point te gebruiken:",
    "Did you know?" : "Wist je dat?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Door \"?format=json\" aan het eind van de URL te zetten, krijg je het resultaat in JSON formaat!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/nl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info niet beschikbaar",
    "Load average" : "Gemiddelde belasting",
    "Last minute" : "Laatste minuut",
    "Memory info not available" : "Geheugeninfo niet beschikbaar",
    "Total" : "Totaal",
    "Current usage" : "Huidig gebruik",
    "Users" : "Gebruikers",
    "Groups" : "Groepen",
    "Links" : "Links",
    "Mails" : "Mails",
    "Federated sent" : "Gefedereerd verstuurd",
    "Federated received" : "Gefedereerd ontvangen",
    "Talk conversations" : "Talk-gesprekken",
    "24 hours" : "24 uur",
    "1 hour" : "1 uur",
    "5 mins" : "5 min",
    "Copy" : "Kopiëren",
    "Copied!" : "Gekopieerd",
    "Not supported!" : "Niet ondersteund",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "System" : "Systeem",
    "Monitoring" : "Monitoren",
    "Monitoring app with useful server information" : "Monitor app met nuttige serverinformatie",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Toont nuttige serverinformatie, zoals CPU belasting, RAM gebruik, disk gebruik, aantal gebruikers, etc.",
    "Operating System" : "Operating System",
    "CPU" : "CPU",
    "Memory" : "Geheugen",
    "Server time" : "Servertijd",
    "Uptime" : "Uptime",
    "Time Servers" : "Tijdservers",
    "Load" : "Belasting",
    "Disk" : "Schijf",
    "Mount" : "Koppeling",
    "Filesystem" : "Bestandssysteem",
    "Size" : "Grootte",
    "Available" : "Beschikbaar",
    "Used" : "Gebruikt",
    "You will get a notification once one of your disks is nearly full." : "Je krijgt een melding als een van je schijven bijna vol is.",
    "Files:" : "Bestanden:",
    "Storages:" : "Opslag:",
    "Free Space:" : "Vrije ruimte:",
    "Network" : "Netwerk",
    "Hostname" : "Hostname",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Status",
    "Speed" : "Snelheid",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Actieve gebruikers",
    "Total users:" : "Totaal aantal gebruikers:",
    "Shares" : "Shares",
    "PHP" : "PHP",
    "Version:" : "Versie:",
    "Memory Limit:" : "Geheugenlimiet:",
    "Max Execution Time:" : "Max verwerkingstijd:",
    "Upload max size:" : "Max uploadomvang:",
    "Database" : "Database",
    "Type:" : "Type:",
    "Size:" : "Grootte:",
    "External monitoring tool" : "Externe monitoring tool",
    "You can connect an external monitoring tool by using this end point:" : "Je kunt een externe monitor-tool verbinden door dit end point te gebruiken:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Wanneer je \"?format=json\" toevoegt aan het einde van de URL ontvang je het resultaat in JSON",
    "Last 24 hours" : "Laatste 24 uur",
    "Last 1 hour" : "Laatste uur",
    "Last 5 mins" : "Laatste 5 minuten",
    "CPU load" : "CPU belasting",
    "Memory usage" : "Geheugengebruik",
    "Storage" : "Opslag",
    "Users:" : "Gebruikers:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Apps geïnstalleerd:",
    "Apps updates available:" : "App updates beschikbaar:",
    "Did you know?" : "Wist je dat?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Door \"?format=json\" aan het eind van de URL te zetten, krijg je het resultaat in JSON formaat!"
},
"nplurals=2; plural=(n != 1);");
